;------------------------------------------------------------------------------
;
;
;                             Volume Control Demo
;
;
;------------------------------------------------------------------------------
;
;
; This simple snippet will attempt to describe just how you can
; create a custom volume control on your dialogs that can be utilized
; without having to use MDX or other such DLL manipulators.
;
;
; This is, by no way, a means to interpret an advanced volume control.
; This was simply created to give 'some' users, not all of you advanced
; out there, a different sort of perspective on certain 'customizable'
; controls. Granted, using MDX and all that sort may be a tad quicker
; and what-not, but I mean, come on, innovation is sometimes fun ;-)

; [ Load Event ]
ON *:LOAD:return $input(Volume Control Demo Loaded! $+ $crlf $+ $crlf $+ To begin $+ $chr(44) simply type: $+ $crlf $+ $crlf $+ /volume.control,io,Successfully Loaded Script)


; [ Aliases/Identifiers ]
; $vc() is a calculator identifier that will allows us calculations
; for the VolumeControl $vol(), most importantly since we have 6 icon objects
; being used, we must divide the maximum 'Master' volume, or 65535, by 6, thus
; each bar represents '10922.5' of volume. $vc(N) will calculate 1-6 based on
; this.

alias -l vc return $calc(10922.5 * $1)

; /volume.control is used to initiate the dialog box for the Volume Control.
; It really serves no purpose other than initiating the demo dialog.

alias volume.control $iif(!$dialog(volume.control),dialog -m volume.control volume.control,return $input(Volume control demo already open.,io,Dialog Active))

; /vol.check is used to update the icons based on the volume when the dialog
; starts. At first, I was going to add a timer that would continually monitor
; the system's master volume, but this is more of an extended feature that
; a user should monitor.

alias -l vol.check {
  ; 10922.5 is the divisible number 6 which adds up to the maximum
  ; master volume for /vol, ie: 65535.
  var %v = $vol(master), %s = vol.set, %r = return, %i = 1

  ; This next line, we want to make sure that the Master Volume is not set to
  ; 'Mute'. If it is, it will perform '/vol.set' and set the value to 0, or
  ; empty. It will then end this command.

  if ($vol(master).mute) { %s 0 | %r }

  ; Next, we want to loop through %i, which is initially set to 1, until it
  ; reaches 6. This loop will determine what the incoming volume selected
  ; should be set as with our icons. ie: if the volume is at 11024.5, the
  ; only highlighted box would be the first one.

  while (%i <= 6) {
    if (%v <= $vc(%i)) { %s %i | %r }
    inc %i
  }

}

; /vol.set is the command used to set both the highlighted portions of our
; volume control, or the green boxes, as well as the gray boxes; it is also
; responsible for actually setting the system's Master Volume.

alias -l vol.set {
  var %o = $1, %1 = %o, %i, %d = volume.control, %f = $scriptdir

  ; The first loop we encounter is for the green volume highlighters. This loop
  ; will first fill every box with green, for the sake of making things easier
  ; on the next loop function.

  while (%1) {
    did -g %d %1 $+(",%f,fill1.bmp,")
    dec %1
  }

  ; Here, we set the value of %i to whatever the incoming number that was
  ; supposedly selected. When it comes directly from clicking on one of the
  ; volume bars in the dialog, it is in the form of the volume box clicked.
  ; When it comes from the /vol.check, it will be what the division calculator
  ; has found the correct number of the box to be highlighted.

  %i = $calc(%o + 1)

  ; Our next loop here checks to make sure that the number that has been
  ; specified with the '/vol.set N' command is not NULL and also greater than 0,
  ; as well as making sure that the number is less than or equal to six. This is
  ; simply an error-checking feature that I've decided to toss in here for
  ; error-safe concerns. The loop will increase %i by 1 until it has reached all
  ; of the numbers up to and including 6; what it's actually doing is taking care
  ; of the gray boxes, seeing which ones need to be changed.

  while (($calc(6 - %o)) && (%i <= 6)) {
    did -g %d %i $+(",%f,fill0.bmp,")
    inc %i
  }

  ; Finally, we will use the number originally sent along with the /vol.set
  ; command to actually set the Master Volume of the system.

  vol -v $vc(%o)
}

; [ Dialog Box ]
dialog -l volume.control {
  title "Volume Control Demo"
  size -1 -1 165 150
  option dbu
  box "Basic Volume Control Demo", 7, 3 3 159 129
  icon 1, 11 36 4 5, " $+ $scriptdirfill1.bmp $+ ", noborder top
  icon 2, 16 34 4 6, " $+ $scriptdirfill1.bmp $+ ", noborder top
  icon 3, 22 32 4 7, " $+ $scriptdirfill1.bmp $+ ", noborder top
  icon 4, 28 30 4 8, " $+ $scriptdirfill1.bmp $+ ", noborder top
  icon 5, 34 28 4 9, " $+ $scriptdirfill1.bmp $+ ", noborder top
  icon 6, 40 26 4 10, " $+ $scriptdirfill1.bmp $+ ", noborder top
  text "This is a very simple volume control that I created as a simplistic way to show just what exactly you might still be able to accomplish with simple mIRC intuition and innovation.", 8, 51 15 108 27
  text "The control is easily created through the use of a few green and gray colored images. Basically, all that you must do is create an image of your choice, with the proper width/height requirements. Assuming you want 3D, all that is needed is to measure a few width/height restrictions, but creating solid colors is a lot easier. Just figure out what about 2-3 pixels larger than your width/height your largest bar is and create one. Then, all you must do is circle through which 'picture' object the user clicks and change the color based on which one they click, as well as replace green with gray on the objects that are to the right of the currently selected bar. Also, make sure that you remember to increase/decrease volume as this is happening. ENJOY!", 9, 6 43 153 87
  button "&OK", 10, 129 135 30 12, ok
}

; [ Dialog Box Events ]
ON *:DIALOG:volume.control:*:*: {

  ; This line is a little trick I usually do with all of my dialogs. I
  ; simply like to set a few values off hand into small, temporary /var
  ; variables. This way, you save space and time with recollection later
  ; on.
  ;
  ; In this instance, I have set the id of the object triggering the
  ; event, or $did, to %i and the type of event, $devent, to %e.

  var %i = $did, %e = $devent

  ; Here we will check to ensure that upon the initial opening of the
  ; volume control dialog, the volume in the computer is analyzed and set
  ; accordingly through the use of 'vol.check'. See: 'alias vol.check'
  ; for additional information.

  if (%e == init) vol.check

  ; The next two lines serve as the overall actions and purpose for this
  ; dialog, which is to demonstrate how the 'volume' objects/pictures act
  ; when a user clicks on one or another of them.
  ;
  ; Here, we are simply checking to make sure that the event was a
  ; 'single-click' and that the $did, which is stored in %i, was valid, 
  ; ie: not 0, as well as checking to make sure that the value was less
  ; than or equal to 6. This helps because we need to be careful with
  ; handling clicks on objects such as the dialog itself and the 'OK'
  ; button. As long as we make sure the value is never 0 and 6 or less,
  ; then we can always be sure it's one of the volume control icons.
  ;
  ; See: 'alias vol.set' for additional information.

  if (%e == sclick) {
    if ((%i) && (%i <= 6)) vol.set %i
  }
}

; [ Menu ]
menu status {
  Volume Control Demo
  .Unload:echo -a Volume Control Demo Unloaded. | .unload -rs $script
}
